@@ -1,8 +1,7 @@
 """QAPyTest is a powerful package for QA specialists built on top of Pytest."""
 
 from qapytest._attach import attach
-from qapytest._graphql import GraphQLClient
-from qapytest._http import HttpClient
+from qapytest._client_http import GraphQLClient, HttpClient
 from qapytest._json_validation import validate_json
 from qapytest._redis import RedisClient
 from qapytest._soft_assert import soft_assert
